==> ejc-sale-impl-3.0.0-20220818.035037-208-sources.jar: com/ejianc/business/sale/bean/ManualshipmentEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发货管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_manualshipment")
public class  ManualshipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="unit_id")
    private Long unitId; // 机组主键
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="ship_dates")
    private String shipDates; // 发货年月日
    @TableField(value="temperature")
    private Long temperature; // 温度
    @TableField(value="car_id")
    private Long carId; // 车辆主键
    @TableField(value="number_plate_id")
    private Long numberPlateId; // 车号id
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="receipts")
    private String receipts; // 收款情况
    @TableField(value="gross_weight")
    private BigDecimal grossWeight; // 毛重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="shippers_id")
    private Long shippersId; // 运输单位主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输单位名称
    @TableField(value="distance")
    private BigDecimal distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="remake")
    private String remake; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="shipment_type")
    private Integer shipmentType; // 发货类型  0-手动发货 1-自动发货
    @TableField(value="freight_status")
    private Integer freightStatus; // 运费确认标志  0-已确认 1-未确认
    @TableField(value="freight_time")
    private Date freightTime; // 运费确认时间
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 确认数
    @TableField(value="receipt_status")
    private Integer receiptStatus; // 回执单状态  0-已勾  1-未勾
    @TableField(value="paid_money")
    private BigDecimal paidMoney; // 已付运费
    @TableField(value="outstanding_money")
    private BigDecimal outstandingMoney; // 未付运费
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="order_name")
    private String orderName; // 联系人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="inspection")
    private String inspection; // 检验
    @TableField(value="print_customer")
    private String printCustomer; // 打印客户名
    @TableField(value="print_construction")
    private String printConstruction; // 打印工地名称
    @TableField(value="print_products")
    private String printProducts; // 打印产品名
    @TableField(value="print_supplier")
    private String printSupplier; // 打印供货商
    @TableField(value="print_shippers_name")
    private String printShippersName; // 打印运输商名称
    @TableField(value="reason")
    private String reason; // 变更原因
    @TableField(value="abstracts")
    private String abstracts; // 确认数备注
    @TableField(value="task_id")
    private String taskId; // 生产任务单id
    @TableField(value="unitdistribute_id")
    private String unitdistributeId; // 分配机组id
    @TableField(value="old_task_id")
    private String oldTaskId; // 老erp系统生产任务编号
    @TableField(value="print_admixture")
    private String printAdmixture; // 打印外加剂
    @TableField(value="product_unit_price")
    private BigDecimal productUnitPrice; // 产品单价
    @TableField(value="money")
    private BigDecimal money; // 金额
    @TableField(value="weighing_number")
    private BigDecimal weighingNumber; // 过磅数


    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public Long getTemperature() {
        return temperature;
    }

    public void setTemperature(Long temperature) {
        this.temperature = temperature;
    }
    public Long getCarId() {
        return carId;
    }

    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }
    public String getReceipts() {
        return receipts;
    }

    public void setReceipts(String receipts) {
        this.receipts = receipts;
    }
    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public String getRemake() {
        return remake;
    }

    public void setRemake(String remake) {
        this.remake = remake;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getShipmentType() {
        return shipmentType;
    }

    public void setShipmentType(Integer shipmentType) {
        this.shipmentType = shipmentType;
    }

    public Integer getFreightStatus() {
        return freightStatus;
    }

    public void setFreightStatus(Integer freightStatus) {
        this.freightStatus = freightStatus;
    }

    public Date getFreightTime() {
        return freightTime;
    }

    public void setFreightTime(Date freightTime) {
        this.freightTime = freightTime;
    }

    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }

    public Integer getReceiptStatus() {
        return receiptStatus;
    }

    public void setReceiptStatus(Integer receiptStatus) {
        this.receiptStatus = receiptStatus;
    }

    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }

    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }

    public Long getNumberPlateId() {
        return numberPlateId;
    }

    public void setNumberPlateId(Long numberPlateId) {
        this.numberPlateId = numberPlateId;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }

    public String getInspection() {
        return inspection;
    }

    public void setInspection(String inspection) {
        this.inspection = inspection;
    }

    public String getPrintCustomer() {
        return printCustomer;
    }

    public void setPrintCustomer(String printCustomer) {
        this.printCustomer = printCustomer;
    }

    public String getPrintConstruction() {
        return printConstruction;
    }

    public void setPrintConstruction(String printConstruction) {
        this.printConstruction = printConstruction;
    }

    public String getPrintProducts() {
        return printProducts;
    }

    public void setPrintProducts(String printProducts) {
        this.printProducts = printProducts;
    }

    public String getPrintSupplier() {
        return printSupplier;
    }

    public void setPrintSupplier(String printSupplier) {
        this.printSupplier = printSupplier;
    }

    public String getShipDates() {
        return shipDates;
    }

    public void setShipDates(String shipDates) {
        this.shipDates = shipDates;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getUnitdistributeId() {
        return unitdistributeId;
    }

    public void setUnitdistributeId(String unitdistributeId) {
        this.unitdistributeId = unitdistributeId;
    }

    public String getPrintShippersName() {
        return printShippersName;
    }

    public void setPrintShippersName(String printShippersName) {
        this.printShippersName = printShippersName;
    }

    public String getOldTaskId() {
        return oldTaskId;
    }

    public void setOldTaskId(String oldTaskId) {
        this.oldTaskId = oldTaskId;
    }

    public String getPrintAdmixture() {
        return printAdmixture;
    }

    public void setPrintAdmixture(String printAdmixture) {
        this.printAdmixture = printAdmixture;
    }

    public BigDecimal getProductUnitPrice() {
        return productUnitPrice;
    }

    public void setProductUnitPrice(BigDecimal productUnitPrice) {
        this.productUnitPrice = productUnitPrice;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getWeighingNumber() {
        return weighingNumber;
    }

    public void setWeighingNumber(BigDecimal weighingNumber) {
        this.weighingNumber = weighingNumber;
    }
}

==> ejc-sale-impl-3.0.0-20220818.073615-209-sources.jar: com/ejianc/business/sale/bean/ManualshipmentEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发货管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_manualshipment")
public class  ManualshipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="unit_id")
    private Long unitId; // 机组主键
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="ship_dates")
    private String shipDates; // 发货年月日
    @TableField(value="temperature")
    private Long temperature; // 温度
    @TableField(value="car_id")
    private Long carId; // 车辆主键
    @TableField(value="number_plate_id")
    private Long numberPlateId; // 车号id
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="receipts")
    private String receipts; // 收款情况
    @TableField(value="gross_weight")
    private BigDecimal grossWeight; // 毛重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="shippers_id")
    private Long shippersId; // 运输单位主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输单位名称
    @TableField(value="distance")
    private BigDecimal distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="remake")
    private String remake; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="shipment_type")
    private Integer shipmentType; // 发货类型  0-手动发货 1-自动发货
    @TableField(value="freight_status")
    private Integer freightStatus; // 运费确认标志  0-已确认 1-未确认
    @TableField(value="freight_time")
    private Date freightTime; // 运费确认时间
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 确认数
    @TableField(value="receipt_status")
    private Integer receiptStatus; // 回执单状态  0-已勾  1-未勾
    @TableField(value="paid_money")
    private BigDecimal paidMoney; // 已付运费
    @TableField(value="outstanding_money")
    private BigDecimal outstandingMoney; // 未付运费
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="order_name")
    private String orderName; // 联系人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="inspection")
    private String inspection; // 检验
    @TableField(value="print_customer")
    private String printCustomer; // 打印客户名
    @TableField(value="print_construction")
    private String printConstruction; // 打印工地名称
    @TableField(value="print_products")
    private String printProducts; // 打印产品名
    @TableField(value="print_supplier")
    private String printSupplier; // 打印供货商
    @TableField(value="print_shippers_name")
    private String printShippersName; // 打印运输商名称
    @TableField(value="reason")
    private String reason; // 变更原因
    @TableField(value="abstracts")
    private String abstracts; // 确认数备注
    @TableField(value="task_id")
    private String taskId; // 生产任务单id
    @TableField(value="unitdistribute_id")
    private String unitdistributeId; // 分配机组id
    @TableField(value="old_task_id")
    private String oldTaskId; // 老erp系统生产任务编号
    @TableField(value="print_admixture")
    private String printAdmixture; // 打印外加剂
    @TableField(value="product_unit_price")
    private BigDecimal productUnitPrice; // 产品单价
    @TableField(value="money")
    private BigDecimal money; // 金额
    @TableField(value="weighing_number")
    private BigDecimal weighingNumber; // 过磅数
    @TableField(value="weighing_time")
    private Date weighingTime; // 过磅时间



    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public Long getTemperature() {
        return temperature;
    }

    public void setTemperature(Long temperature) {
        this.temperature = temperature;
    }
    public Long getCarId() {
        return carId;
    }

    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }
    public String getReceipts() {
        return receipts;
    }

    public void setReceipts(String receipts) {
        this.receipts = receipts;
    }
    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public String getRemake() {
        return remake;
    }

    public void setRemake(String remake) {
        this.remake = remake;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getShipmentType() {
        return shipmentType;
    }

    public void setShipmentType(Integer shipmentType) {
        this.shipmentType = shipmentType;
    }

    public Integer getFreightStatus() {
        return freightStatus;
    }

    public void setFreightStatus(Integer freightStatus) {
        this.freightStatus = freightStatus;
    }

    public Date getFreightTime() {
        return freightTime;
    }

    public void setFreightTime(Date freightTime) {
        this.freightTime = freightTime;
    }

    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }

    public Integer getReceiptStatus() {
        return receiptStatus;
    }

    public void setReceiptStatus(Integer receiptStatus) {
        this.receiptStatus = receiptStatus;
    }

    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }

    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }

    public Long getNumberPlateId() {
        return numberPlateId;
    }

    public void setNumberPlateId(Long numberPlateId) {
        this.numberPlateId = numberPlateId;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }

    public String getInspection() {
        return inspection;
    }

    public void setInspection(String inspection) {
        this.inspection = inspection;
    }

    public String getPrintCustomer() {
        return printCustomer;
    }

    public void setPrintCustomer(String printCustomer) {
        this.printCustomer = printCustomer;
    }

    public String getPrintConstruction() {
        return printConstruction;
    }

    public void setPrintConstruction(String printConstruction) {
        this.printConstruction = printConstruction;
    }

    public String getPrintProducts() {
        return printProducts;
    }

    public void setPrintProducts(String printProducts) {
        this.printProducts = printProducts;
    }

    public String getPrintSupplier() {
        return printSupplier;
    }

    public void setPrintSupplier(String printSupplier) {
        this.printSupplier = printSupplier;
    }

    public String getShipDates() {
        return shipDates;
    }

    public void setShipDates(String shipDates) {
        this.shipDates = shipDates;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getUnitdistributeId() {
        return unitdistributeId;
    }

    public void setUnitdistributeId(String unitdistributeId) {
        this.unitdistributeId = unitdistributeId;
    }

    public String getPrintShippersName() {
        return printShippersName;
    }

    public void setPrintShippersName(String printShippersName) {
        this.printShippersName = printShippersName;
    }

    public String getOldTaskId() {
        return oldTaskId;
    }

    public void setOldTaskId(String oldTaskId) {
        this.oldTaskId = oldTaskId;
    }

    public String getPrintAdmixture() {
        return printAdmixture;
    }

    public void setPrintAdmixture(String printAdmixture) {
        this.printAdmixture = printAdmixture;
    }

    public BigDecimal getProductUnitPrice() {
        return productUnitPrice;
    }

    public void setProductUnitPrice(BigDecimal productUnitPrice) {
        this.productUnitPrice = productUnitPrice;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public BigDecimal getWeighingNumber() {
        return weighingNumber;
    }

    public void setWeighingNumber(BigDecimal weighingNumber) {
        this.weighingNumber = weighingNumber;
    }

    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
}
